@@ -2,35 +2,25 @@ from datetime import date
 
 from cubicweb.entities import AnyEntity, fetch_config
 from cubicweb.entities.adapters import IMileStoneAdapter
-from cubicweb.web.views.ibreadcrumbs import IBreadCrumbsAdapter
 from cubicweb.selectors import is_instance
 
 class Order(AnyEntity):
     __regid__ = 'Order'
     fetch_attrs, fetch_order = fetch_config(('title', 'date'))
 
-    def update_progress(self):
+    def update_progress(self, compute=True):
         """callable only on the server side"""
-        workorders = self.split_into
-        self.budget = sum(wod.budget or 0 for wod in workorders)
-        self.progress_target = sum(wod.progress_target or 0 for wod in workorders)
-        self.progress_done = sum(wod.progress_done or 0 for wod in workorders)
-        self.progress_todo = sum(wod.progress_todo or 0 for wod in workorders)
-        self._cw.execute('SET W budget %(budget)s, '
-                         'W progress_target %(target)s, '
-                         'W progress_done %(done)s, '
-                         'W progress_todo %(todo)s '
-                         'WHERE W eid %(eid)s',
-                         {'eid': self.eid,
-                          'budget': self.budget,
-                          'target': self.progress_target,
-                          'done': self.progress_done,
-                          'todo': self.progress_todo})
+        if compute:
+            workorders = self.split_into
+            self.set_attributes(
+                budget=sum(wod.budget or 0 for wod in workorders),
+                progress_done=sum(wod.progress_done or 0 for wod in workorders),
+                progress_todo=sum(wod.progress_todo or 0 for wod in workorders))
 
     # XXX used somewhere? If so must be in an adapter
     def progress_info(self):
-        return {'estimated': self.progress_target,
-                'estimatedcorrected': self.progress_target,
+        return {'estimated': self.budget,
+                'estimatedcorrected': self.budget,
                 'done': self.progress_done,
                 'todo': self.progress_todo,
                 }
@@ -52,32 +42,10 @@ class WorkOrder(AnyEntity):
     def order(self):
         return self.reverse_split_into[0]
 
-    def _compute_progress(self):
-        self.progress_target = self.budget or 0
-        self.progress_done = 0
-        self.progress_todo = max(0, self.progress_target - self.progress_done)
-
-    def update_progress(self):
+    def update_progress(self, compute=True):
         """callable only on the server side"""
-        self._compute_progress()
-        self._cw.execute('SET W progress_target %(target)s, '
-                         'W progress_done %(done)s, '
-                         'W progress_todo %(todo)s '
-                         'WHERE W eid %(eid)s',
-                         {'eid': self.eid,
-                          'target': self.progress_target,
-                          'done': self.progress_done,
-                          'todo': self.progress_todo})
-        if self.reverse_split_into:
-            self.order.update_progress()
-        else:
-            self.debug('should have a order as parent')
-
-class WorkOrderIBreadCrumbsAdapter(IBreadCrumbsAdapter):
-    __select__ = is_instance('WorkOrder')
-
-    def parent_entity(self):
-        return self.entity.order
+        for order in self.reverse_split_into:
+            order.update_progress(True)
 
 
 class WorkOrderIMileStoneAdapter(IMileStoneAdapter):
@@ -109,8 +77,8 @@ class WorkOrderIMileStoneAdapter(IMileStoneAdapter):
         return self.entity.cw_adapt_to('IWorkflowable').state == u'in progress'
 
     def progress_info(self):
-        return {'estimated': self.entity.progress_target,
-                'estimatedcorrected': self.entity.progress_target,
+        return {'estimated': self.entity.budget,
+                'estimatedcorrected': self.entity.budget,
                 'done': self.entity.progress_done,
                 'todo': self.entity.progress_todo,}
 
