@@ -1,10 +1,5 @@
 from yams.buildobjs import (EntityType, SubjectRelation, ObjectRelation,
-                            String, Date, Float)
-try:
-    from yams.buildobjs import RichString
-except ImportError:
-    from cubicweb.schema import RichString
-
+                            String, Date, Float, RichString)
 from cubicweb.schema import RQLConstraint, WorkflowableEntityType
 
 _ = unicode
@@ -16,10 +11,10 @@ class Order(WorkflowableEntityType):
 
     # computed attributes
     budget = Float(description=_('computed attribute'))
-    progress_target = Float(description=_('computed attribute'))
     progress_done = Float(description=_('computed attribute'))
     progress_todo = Float(description=_('computed attribute'))
 
+
 class WorkOrder(WorkflowableEntityType):
     title = String(required=True, fulltextindexed=True, indexed=True, maxsize=128)
     description = RichString(fulltextindexed=True)
@@ -28,6 +23,5 @@ class WorkOrder(WorkflowableEntityType):
     end_date = Date(description=_('date work order will end on'))
 
     # computed attributes
-    progress_target = Float(description=_('computed attribute'))
     progress_done = Float(description=_('computed attribute'))
     progress_todo = Float(description=_('computed attribute'))
